@@ -58,14 +58,22 @@ function addr_display_result($res, $includesource = true) {
     addr_insert_hidden();
     $line = 0;
 
+    bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+    textdomain('abook_group');
     echo '<TABLE BORDER=0 WIDTH="98%" ALIGN=center>' .
          '<TR BGCOLOR="' . $color[9] . '"><TH ALIGN=left>&nbsp;' .
          '<TH ALIGN=left>&nbsp;' . _("Name") .
          '<TH ALIGN=left>&nbsp;' . _("E-mail") .
          '<TH ALIGN=left>&nbsp;' . _("Info");
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
 
     if ($includesource) {
+        bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+        textdomain('abook_group');
         echo '<TH ALIGN=left WIDTH="10%">&nbsp;' . _("Source");
+        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+        textdomain('squirrelmail');
     }
 
     echo "</TR>\n";
@@ -91,11 +99,15 @@ function addr_display_result($res, $includesource = true) {
     }
     echo '<TR><TD ALIGN=center COLSPAN=';
     if ($includesource) { echo '4'; } else { echo '5'; }
-    echo '><INPUT TYPE=submit NAME="addr_search_done" VALUE="' .
-         _("Use Addresses") . '"></TD></TR>' .
-         '</TABLE>' .
-         '<INPUT TYPE=hidden VALUE=1 NAME="html_addr_search_done">' .
-         '</FORM>';
+        bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+       textdomain('abook_group');
+        echo '><INPUT TYPE=submit NAME="addr_search_done" VALUE="' .
+             _("Use Addresses") . '"></TD></TR>' .
+             '</TABLE>' .
+             '<INPUT TYPE=hidden VALUE=1 NAME="html_addr_search_done">' .
+             '</FORM>';
+             bindtextdomain('squirrelmail', SM_PATH . 'locale');
+             textdomain('squirrelmail');
 }
 
 /* --- End functions --- */
@@ -121,10 +133,19 @@ insert_javascript();
 
 <table width="95%" align=center cellpadding=2 cellspacing=2 border=0>
 <tr><td bgcolor="<?php echo $color[0] ?>">
-   <center><b><?php echo _("Groups") ?></b></center>
+   <center><b>
+<?php 
+    bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+    textdomain('abook_group');
+    echo _("Groups");
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
+
+?>
+</b></center>
 </td></tr></table>
 <?php if (count($myGroups)>0) { ?>
-<table> <tr><td></td><td>Groupname</td></tr>
+<table> <tr><td></td><td></td></tr>
 <?php
 for ($i=0;$i<count($myGroups);$i++){
     $groupName = $myGroups[$i]['addressgroup'];
@@ -145,7 +166,11 @@ for ($i=0;$i<count($myGroups);$i++){
 <?php
 }
 else{
-    echo  "There are no groups available for selection";
+    bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+    textdomain('abook_group');
+    echo  _("There are no groups available for selection");
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
 }
 ?>
 </body></html>
