@@ -94,7 +94,7 @@ $abookGroups->personal_abook_table = "address";
 $abookGroups->global_abook_table = "globaladdress";
 
 //displayHtmlHeader();
-displayPageHeader($color, $mailbox);
+displayPageHeader($color, 'None');
 /* Initialize vars */
 if (!isset($query) || isset($listall)) { $query = ''; }
 if (!isset($show))  { $show  = ''; }
@@ -309,19 +309,13 @@ elseif (!empty($addToGroup)) {
      }
 ?>
   </select>
-   <input type="submit" name="addToGroup" value="
-      <?php 
-       bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
-       textdomain('abook_group');
-       echo _("Add");
-       bindtextdomain('squirrelmail', SM_PATH . 'locale');
-       textdomain('squirrelmail');
-      ?>
-   ">
-  </TD></TR>
- <?php
+<?php 
   bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
   textdomain('abook_group');
+  echo ' <input type="submit" name="addToGroup" value="' . _("Add") . '">';
+?>
+  </TD></TR>
+ <?php
   echo '<TR><TD>&nbsp; ' . _("OR") . '</TD></TR>';
   bindtextdomain('squirrelmail', SM_PATH . 'locale');
   textdomain('squirrelmail');
@@ -332,23 +326,18 @@ elseif (!empty($addToGroup)) {
   bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
   textdomain('abook_group');
   echo _("Add to New Group (supply group name):");
-  bindtextdomain('squirrelmail', SM_PATH . 'locale');
-  textdomain('squirrelmail');
 ?>
    <input type="text" name="newGroup">
-   <input type="submit" name="addNewGroup" value="
-      <?php 
-       bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
-       textdomain('abook_group');
-       echo _("Add");
+<?php 
+   echo ' <input type="submit" name="addNewGroup" value="' .  _("Add") . '">';
        bindtextdomain('squirrelmail', SM_PATH . 'locale');
        textdomain('squirrelmail');
-      ?>
-  ">
+?>
+
  </TD></TR>
  <?php
  }
- echo "</TABLE></FORM>\n";
+echo "</TABLE></FORM>\n";
 
 display_abook_group_footer();
 
